@@ -247,19 +247,22 @@ sub _fmt_quality {
 
 sub _choose_fmt {
     my ( $opt, $info, $video_id ) = @_;
+    my $fmt_to_info = $info->{$video_id}{fmt_to_info};
     my ( @choices, @format_ids );
-    my @fmts;
     if ( $info->{$video_id}{extractor_key} eq 'Youtube' ) {
-        for my $fmt ( sort { $a <=> $b } keys %{$info->{$video_id}{fmt_to_info}} ) {
-            my ( $fmt, $desc ) = split '\s*-\s*', $info->{$video_id}{fmt_to_info}{$fmt}{format};
-            $desc = '' if ! $desc;
-            push @choices, sprintf '%3s - %s %s', $fmt, $desc, $info->{$video_id}{fmt_to_info}{$fmt}{ext};
+        for my $fmt ( sort { $a <=> $b } keys %$fmt_to_info ) {
+            if ( $fmt_to_info->{$fmt}{format} =~ /^\Q$fmt\E\s*-\s*(.+)\z/ ) {
+                push @choices, sprintf '%3s - %s %s', $fmt, $1, $fmt_to_info->{$fmt}{ext};
+            }
+            else {
+                push @choices, $fmt_to_info->{$fmt}{format} . ' ' . $fmt_to_info->{$fmt}{ext};
+            }
             push @format_ids, $fmt;
         }
     }
     else {
-        for my $fmt ( sort { $a cmp $b } keys %{$info->{$video_id}{fmt_to_info}} ) {
-            push @choices, $info->{$video_id}{fmt_to_info}{$fmt}{format} . ' ' . $info->{$video_id}{fmt_to_info}{$fmt}{ext};
+        for my $fmt ( sort { $a cmp $b } keys %$fmt_to_info ) {
+            push @choices, $fmt_to_info->{$fmt}{format} . ' ' . $fmt_to_info->{$fmt}{ext};
             push @format_ids, $fmt;
         }
     }
